@@ -98,7 +98,7 @@ public class MailCategoriesConfigConverter implements ResultConverter {
     public void convert(AJAXRequestData requestData, AJAXRequestResult result, ServerSession session, Converter converter) throws OXException {
         try {
             convert2JSON(requestData, result, session);
-        } catch (final JSONException e) {
+        } catch (JSONException e) {
             throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
         }
     }
@@ -121,11 +121,11 @@ public class MailCategoriesConfigConverter implements ResultConverter {
             return;
         }
         
-        if(resultObject instanceof List){ 
+        if (resultObject instanceof List){ 
             @SuppressWarnings("unchecked")
             List<MailCategoryConfig> list = (List<MailCategoryConfig>) resultObject;
             
-            if(list==null || list.isEmpty()){
+            if (list==null || list.isEmpty()){
                 result.setResultObject(JSONObject.NULL, "json");
                 return;
             }
